@@ -1,6 +1,10 @@
-from transformers import DetrFeatureExtractor, DetrForObjectDetection, pipeline
-from PIL import Image
+import os
+from datetime import datetime
+
 import torch
+from transformers import DetrFeatureExtractor, DetrForObjectDetection, pipeline
+
+from PIL import Image
 
 import matplotlib
 matplotlib.use('agg')
@@ -72,7 +76,13 @@ class ObjectDetectionInference:
           ax.text(xmin, ymin, text, fontsize=15, bbox=dict(facecolor='yellow', alpha=0.5))
 
       plt.axis('off')
-      plt.savefig("./out_img/3.jpg")
+
+      IMG_OUT = "./out_img/"
+
+      if not os.path.exists(IMG_OUT):
+        os.makedirs(IMG_OUT)
+
+      plt.savefig(IMG_OUT + datetime.today().strftime("%Y-%m-%d-%H-%M-%S") + ".jpg")
 
   def visualize_predictions(self, image, outputs, threshold=0.2):
 
@@ -103,7 +113,7 @@ class ObjectDetectionInference:
   ⚙️ Predict the bounding boxes for each object in the image
   Return: image, probas, bboxes_scaled
   """
-  def predict(self, img_path: str):
+  def predict(self, img_path: str, threshold=0.2):
 
     # Load the image
     image_array = Image.open(img_path)
@@ -123,4 +133,4 @@ class ObjectDetectionInference:
       pixel_mask=None,
     )
     
-    return self.visualize_predictions(image_array, outputs)
+    return self.visualize_predictions(image_array, outputs, threshold)
